@@ -110,7 +110,7 @@ int walk_file_tree(const char *rootname, wft_cb_t callback, void *cbdata)
     wftnode		*np;
     char		*curr_dirname	 = xstrdup(rootname);
     char		*path		 = NULL;
-#ifndef	__FreeBSD__
+#if	!(defined(__FreeBSD__) || defined(__sun))
     struct dirent	entry;
 #endif
     struct dirent	*result;
@@ -127,12 +127,11 @@ int walk_file_tree(const char *rootname, wft_cb_t callback, void *cbdata)
 
       /* while we don't want to go deeper into file tree */
       while (! np->next) {
-#ifndef	__FreeBSD__
+#if	defined(__FreeBSD__) || defined(__sun)
+	result = readdir(np->dir);
+#else
 	if (readdir_r(np->dir, &entry, &result) != 0)
 	  return -1;
-#else
-        /* FreeBSD */
-	result = readdir(np->dir);
 #endif
 	if (!result) {
 	  /* no more entries in this dir */
@@ -165,8 +164,11 @@ int walk_file_tree(const char *rootname, wft_cb_t callback, void *cbdata)
 	  }
 	  if (! (np->next = malloc(sizeof(* np->next))) )
 	    return -1;
-	  if (! (np->next->dir = opendir(path)) )
+	  if (! (np->next->dir = opendir(path)) ) {
+	    fprintf(stderr, "Error: cannot open directory (%s): %s\n",
+		    path, strerror(errno));
 	    return -1;
+	  }
 	  free(curr_dirname);
 	  curr_dirname		 = xstrdup(path);
 	  np->next->next	 = NULL;
