@@ -29,7 +29,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include	<stdlib.h>
 #include	<string.h>
 #include	<errno.h>
-#ifdef __FreeBSD__		/* until FreeBSD conforms to C99 */
+/* until these platforms conform to C99 */
+#if	defined(__FreeBSD__) || defined(__sun)
 #include	<inttypes.h>
 #else
 #include	<stdint.h>
