@@ -22,7 +22,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 #include	<stdio.h>
 #include	<stdlib.h>
-#ifdef __FreeBSD__		/* until FreeBSD conforms to C99 */
+/* until these platforms conform to C99 */
+#if defined(__FreeBSD__) || defined(__sun)
 #include	<inttypes.h>
 #else
 #include	<stdint.h>
